@@ -1,6 +1,7 @@
 import netbox.connection as connection
 import netbox.dcim as dcim
 import netbox.ipam as ipam
+import netbox.virtualization as virtualization
 
 
 class NetBox(object):
@@ -8,3 +9,4 @@ class NetBox(object):
         self.connection = connection.NetboxConnection(host=host, **kwargs)
         self.ipam = ipam.Ipam(self.connection)
         self.dcim = dcim.Dcim(self.connection)
+        self.virtualization = virtualization.Virtualization(self.connection)
